----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
function love.load() 
  love.window.setTitle("Asteroids")
  screenwidth, screenheight = love.window.getDesktopDimensions()
  if love.window.setMode(screenwidth, screenheight) == false then
    print("Error setting window dimensions.")
    love.event.quit()
  end
  if love.window.setFullscreen(true, "desktop") == false then
    print("Error setting fullscreen.")
    love.event.quit()
  end
  -- print("Screen Dimensions: "..screenwidth.." "..screenheight)

  player_ship = love.graphics.newImage("ship.png")  
  asteroid1 = love.graphics.newImage("asteroid1.png")
  pew_image = love.graphics.newImage("pew.png")
  love.graphics.setNewFont(12)
  love.graphics.setBackgroundColor(0,0,0)
  love.graphics.setColor(255,255,255)

  player = {}
  -- player position
  player["x"] = screenwidth / 2
  player["y"] = screenheight / 2
  -- player rotation
  player["r"] = love.math.random(1, 360)
  -- player speed
  player["s"] = 4

  pew = {}
  pew["s"] = 5 -- bullet speed
  totalpews = 5 -- max bullets
  for i=1, totalpews do
    pew[i] = {}
    pew[i]["fired"] = false
  end

  -- How many big asteroids there should be.
  totalasteroids = 8

  
  asteroid = {}
  for i=1, totalasteroids do
    asteroid[i] = {}

    -- asteroid position (won't spawn in the middle)
    if love.math.random(0,1) == 1 then
      asteroid[i]["x"] = love.math.random(1, screenwidth)    
      if love.math.random(0,1) == 1 then
        asteroid[i]["y"] = love.math.random(1, 20)
      else
        asteroid[i]["y"] = love.math.random(screenheight - 20, screenheight)
      end
    else
      asteroid[i]["y"] = love.math.random(1, screenheight)    
      if love.math.random(0,1) == 1 then
        asteroid[i]["x"] = love.math.random(1, 20)
      else
        asteroid[i]["x"] = love.math.random(screenwidth - 20, screenwidth)
      end
    end


    -- rotation
    asteroid[i]["r"] = love.math.random(1, 360)            
    -- rotation speed
    asteroid[i]["rs"] = love.math.random(-180, 180) / 60     

    -- asteroid velocity
    asteroid[i]["xs"] = love.math.random(-200, 200) / 60
    asteroid[i]["ys"] = love.math.random(-200, 200) / 60
  end
end 
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
function love.update(dt)
  for i=1, totalasteroids do
    -- move those naughty asteroids
    asteroid[i].x = asteroid[i].x + asteroid[i].xs
    asteroid[i].y = asteroid[i].y + asteroid[i].ys

    -- make it rotate
    asteroid[i].r = asteroid[i].r + asteroid[i].rs

    -- reset rotation
    if asteroid[i].r > 360 then asteroid[i].r = 0
    elseif asteroid[i].r < 0 then asteroid[i].r = 360 end
    
    -- move asteroid to opposite side
    if asteroid[i].x > screenwidth then
      asteroid[i].x = asteroid[i].x - screenwidth
    elseif asteroid[i].x < 0 then
      asteroid[i].x = asteroid[i].x + screenwidth
    end
    if asteroid[i].y > screenheight then
      asteroid[i].y = asteroid[i].y - screenheight
    elseif asteroid[i].y < 0 then
      asteroid[i].y = asteroid[i].y + screenheight
    end
  end


  -- move the player
  if love.keyboard.isDown('up') then
    player.x = player.x + player.s * math.cos(math.rad(player.r))
    player.y = player.y + player.s * math.sin(math.rad(player.r))
  end
  if love.keyboard.isDown('down') then
    player.x = player.x - player.s * math.cos(math.rad(player.r))
    player.y = player.y - player.s * math.sin(math.rad(player.r))
  end
  if love.keyboard.isDown('left') then
    player.r = player.r - 5
  end
  if love.keyboard.isDown('right') then
    player.r = player.r + 5
  end

  -- reset rotation
  if player.r > 360 then player.r = 0 
  elseif player.r < 0 then player.r = 360 end

  if player.x > screenwidth then
    player.x = player.x - screenwidth
  elseif player.x < 0 then
    player.x = player.x + screenwidth
  end
  if player.y > screenheight then
    player.y = player.y - screenheight
  elseif player.y < screenheight then
    player.y = player.y + screenheight
  end


  love.timer.sleep(.013) -- keep framerate around 60 per second
end
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

-- function love.mousepressed(x, y, button)
--    if button == 'l' then
--    end
-- end

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
function love.draw()
  -- love.graphics.setColor(255,255,255)
  -- love.graphics.setColor(love.math.random(1,255),love.math.random(1,255),love.math.random(1,255))

  for i=1, totalasteroids do
    -- draw asteroid
    love.graphics.draw(asteroid1, asteroid[i].x, asteroid[i].y, math.rad(asteroid[i].r), 1, 1, asteroid1:getWidth()/2, asteroid1:getHeight()/2) 

    -- draw offscreen part of asteroid on opposite side
    if asteroid[i].x > screenwidth - asteroid1:getWidth()/2 then
      love.graphics.draw(asteroid1, asteroid[i].x - screenwidth, asteroid[i].y, math.rad(asteroid[i].r), 1, 1, asteroid1:getWidth()/2, asteroid1:getHeight()/2)
    end
    if asteroid[i].x < asteroid1:getWidth()/2 then
      love.graphics.draw(asteroid1, asteroid[i].x + screenwidth, asteroid[i].y, math.rad(asteroid[i].r), 1, 1, asteroid1:getWidth()/2, asteroid1:getHeight()/2)
    end
    if asteroid[i].y > screenheight - asteroid1:getHeight()/2 then
      love.graphics.draw(asteroid1, asteroid[i].x, asteroid[i].y - screenheight, math.rad(asteroid[i].r), 1, 1, asteroid1:getWidth()/2, asteroid1:getHeight()/2)
    end
    if asteroid[i].y < asteroid1:getHeight()/2 then
      love.graphics.draw(asteroid1, asteroid[i].x, asteroid[i].y + screenheight, math.rad(asteroid[i].r), 1, 1, asteroid1:getWidth()/2, asteroid1:getHeight()/2)
    end
  end

  love.graphics.draw(player_ship, player.x, player.y, math.rad(player.r), 1, 1, player_ship:getWidth()/2, player_ship:getHeight()/2)

  if player.x > screenwidth - player_ship:getWidth()/2 then
    love.graphics.draw(player_ship, player.x - screenwidth, player.y, math.rad(player.r), 1, 1, player_ship:getWidth()/2, player_ship:getHeight()/2)
  end
  if player.x < player_ship:getWidth()/2 then
    love.graphics.draw(player_ship, player.x + screenwidth, player.y, math.rad(player.r), 1, 1, player_ship:getWidth()/2, player_ship:getHeight()/2)
  end
  if player.y > screenheight - player_ship:getHeight()/2 then
    love.graphics.draw(player_ship, player.x, player.y - screenheight, math.rad(player.r), 1, 1, player_ship:getWidth()/2, player_ship:getHeight()/2)
  end
  if player.y < player_ship:getHeight()/2 then
    love.graphics.draw(player_ship, player.x, player.y + screenheight, math.rad(player.r), 1, 1, player_ship:getWidth()/2, player_ship:getHeight()/2)
  end

  for i=1, totalpews do
    if pew[i].fired then
      love.graphics.draw(pew_image, pew[i].x, pew[i].y, math.rad(pew[i].r), 1, 1, pew_image:getWidth()/2, 0)
    end
  end

  -- love.graphics.setColor(255,255,255)
  -- love.graphics.print("blah", 10, 10)
  love.graphics.print("Arrow keys to move, X to fire.", 10, 30)
  love.graphics.print("FPS: "..love.timer.getFPS(), 10, 10)
  k = 30
  for i=1, totalpews do
    k = k + 20
    love.graphics.print("pew["..i.."].fired = "..tostring(pew[i].fired), 10, k)
  end
end
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------


function love.keypressed(key)
  if key == 'x' then
    for i=1, totalpews do
      if pew[i].fired == false then
        pew[i].fired = true
        pew[i].timer = 0
        pew[i].x = player.x
        pew[i].y = player.y
        pew[i].r = player.r
        break
      end
    end
  end

  if key == 'escape' then
    love.event.quit()
  end
end


function love.quit()
  print("App closed.")
end